InputDialog class

Inheritance

Constructors

InputDialog(BuildContext context)

Properties

buttons → List<DialogButton>
finalinherited
context → BuildContext
finalinherited
dialogType ↔ DialogType
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
messageString ↔ String?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
titleString ↔ String?
getter/setter pairinherited

Methods

button(String label, dynamic value, {VoidCallback? onPressed, bool dismiss = true, bool isDefault = false}) → InputDialog
inherited
getInputValue(String label) → String
inputField(String label, {String? initialValue, TextEditingController? controller, bool obscureText = false}) → InputDialog
message(String message) → InputDialog
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show<T>() → Future<T?>
override
title(String title) → InputDialog
inherited
toString() → String
A string representation of this object.
inherited
type(DialogType type) → InputDialog
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited